@@ -1,3 +1,6 @@
+__project__ = "auto_extract"
+__version__ = "0.1.3"
+
 from auto_extract.extract_item import parse_article
 from auto_extract.extract_item import Article
 from auto_extract.crawling.crawler import Crawler
